function [qk,mek]=KuhnTriangulationOrder(d,order)
% FUNCTION fc_hypermesh.CG.KuhnTriangulation: Kuhn's triangulation of the 
%     unit d-hypercube with d! d-simplices.
%
% USAGE
%   [q,me]=fc_hypermesh.CG.KuhnTriangulation(d)
% 
% INPUT
%   d : space dimension.
%
% OUTPUT
%   q : d-by-2^d array. Contains all the vertices of the unit-hypercube.
%   me: (d+1)-by-d! array. Connectivity array of the triangulation.
%
%    Copyright (C) 2016-2019 F. Cuvelier
  [q,me]=fc_hypermesh.CG.KuhnTriangulation(d);
  if order==1
    qk=q;mek=me;
    return;
  end
  QSimRef=order*fc_hypermesh.CG.NodesSimpRef(d,order);
  nQSimRef=size(QSimRef,2);
  beta=fc_hypermesh.CG.beta(order*ones(1,d));
  %qk=fc_hypermesh.CG.TessHyp(ones(1,d),order);
  qk=fc_hypermesh.CG.points(order*ones(1,d))/order;
  nme=size(me,2);numnodes=size(me,1);
  N=factorial(d+order)/(factorial(d)*factorial(order)); % Number of nodes in a Pk-simplex

  mek=zeros(N,factorial(d)); % d! nb of d-simplices in a d-hypercube by Khun Decomposition

  for l=1:nme
    Q=q(:,me(:,l));
    AK=Q(:,2:end)-Q(:,1)*ones(1,numnodes-1);
    QK=AK*QSimRef+order*Q(:,1)*ones(1,nQSimRef);
    mek(:,l)=beta*QK+1;
  end
end
